CustomValueTypeInfo

Trait CustomValueTypeInfo 

pub trait CustomValueTypeInfo {
    type TypeId: Clone;

    // Required method
    fn custom_value_info(
        &self,
        name: &str,
    ) -> Result<CustomValueInfo<'_, Self::TypeId>, CustomValueInfoError>;
}
This can be implemented for anything capable of providing Custom Value information.

Required Associated Types

type TypeId: Clone

The type of type IDs that we are using to obtain type information.

Required Methods

fn custom_value_info( &self, name: &str, ) -> Result<CustomValueInfo<'_, Self::TypeId>, CustomValueInfoError>

Get information about a constant

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl CustomValueTypeInfo for RuntimeMetadataV15

Source

impl CustomValueTypeInfo for RuntimeMetadataV16

Implementors