ViewFunctionTypeInfo

Trait ViewFunctionTypeInfo 

pub trait ViewFunctionTypeInfo {
    type TypeId: Clone;

    // Required method
    fn view_function_info(
        &self,
        pallet_name: &str,
        function_name: &str,
    ) -> Result<ViewFunctionInfo<'_, Self::TypeId>, ViewFunctionInfoError<'_>>;
}
This is implemented for anything capable of providing information about view functions (primarily metadata V16 and onwards).

Required Associated Types

type TypeId: Clone

The type of type IDs that we are using to obtain type information.

Required Methods

fn view_function_info( &self, pallet_name: &str, function_name: &str, ) -> Result<ViewFunctionInfo<'_, Self::TypeId>, ViewFunctionInfoError<'_>>

Get the information needed to decode a specific View Function.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ViewFunctionTypeInfo for RuntimeMetadataV16

Source

type TypeId = u32

Source

fn view_function_info( &self, pallet_name: &str, function_name: &str, ) -> Result<ViewFunctionInfo<'_, Self::TypeId>, ViewFunctionInfoError<'_>>

Implementors